@@ -257,12 +257,37 @@ class DVBDaemonPlugin(totem.Plugin):
 
         gettext.textdomain('gnome-dvb-daemon')
         locale.textdomain('gnome-dvb-daemon')
-        
+
+        self.monitor_bus()
+
+        try:
+            self.construct()
+        except dbus.DBusException:
+            print >> sys.stderr, "Failed activating DVB DBus service"
+            return
+
+    def monitor_bus(self):
+        bus = dbus.SessionBus()
+        # Get proxy object
+        proxy = bus.get_object("org.freedesktop.DBus",
+            "/org/freedesktop/DBus")
+        # Apply the correct interace to the proxy object
+        dbusobj = dbus.Interface(proxy, "org.freedesktop.DBus")
+
+        dbusobj.connect_to_signal("NameOwnerChanged", self.on_dbus_owner_changed)
+
+    def on_dbus_owner_changed(self, name, old_owner, new_owner):
+        if name == DBUS_DVB_SERVICE:
+            if old_owner == "":
+                self.construct()
+            elif new_owner == "":
+                self.deactivate(self.totem_object)
+
+    def construct(self):
+        self.manager = DVBModel()
+
         self.setup = DvbSetup()
         
-        self.manager = DVBModel()
-        self.recentmanager = gtk.recent_manager_get_default()
-
         self.manager.get_all_devices(lambda devs: self.enable_dvb_support(len(devs) > 0))
 
     def enable_dvb_support(self, val):
@@ -521,21 +546,6 @@ class DVBDaemonPlugin(totem.Plugin):
                     url, success = channellist.get_channel_url(sid)
                 self.totem_object.action_remote(totem.REMOTE_COMMAND_REPLACE, url)
                 self.totem_object.action_remote(totem.REMOTE_COMMAND_PLAY, url)
-                # Totem adds the URL to recent manager, remove it again
-                try:
-                    self.recentmanager.remove_item (url)
-                except GError, e:
-                    print >> sys.stderr, \
-                        "Error removing recently used item: %s" % str(e)
-                success = self.recentmanager.add_full (url,
-                    {"display_name": model[aiter][model.COL_NAME],
-                     "app_name": _("Totem Movie Player"),
-                     "app_exec": "totem %u",
-                     "mime_type": "video",
-                     "groups": ("Totem", "gnome-dvb-daemon",)})
-                if not success:
-                    print >> sys.stderr, \
-                        "Error adding recently used item"
         elif event.button == 3:
             # right click button
             x = int(event.x)
